Coverage report

# Coverage report: 24%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 1828 | 1397 | 0 | 24%
F:\DEV\EMIZ\emiz\__init__.py | 8 | 2 | 0 | 75%
F:\DEV\EMIZ\emiz\_parking_spots.py | 1 | 0 | 0 | 100%
F:\DEV\EMIZ\emiz\build.py | 245 | 245 | 0 | 0%
F:\DEV\EMIZ\emiz\dummy_miz.py | 1 | 0 | 0 | 100%
F:\DEV\EMIZ\emiz\mission.py | 874 | 563 | 0 | 36%
F:\DEV\EMIZ\emiz\mission_time.py | 20 | 20 | 0 | 0%
F:\DEV\EMIZ\emiz\mission_weather.py | 160 | 160 | 0 | 0%
F:\DEV\EMIZ\emiz\miz.py | 179 | 146 | 0 | 18%
F:\DEV\EMIZ\emiz\parking_spots.py | 22 | 12 | 0 | 45%
F:\DEV\EMIZ\emiz\parse_parking_spots.py | 17 | 17 | 0 | 0%
F:\DEV\EMIZ\emiz\sltp.py | 250 | 209 | 0 | 16%
F:\DEV\EMIZ\emiz\validator.py | 51 | 23 | 0 | 55%

No items found using the specified filter.